@@ -220,7 +220,10 @@ def generate_backtest_result(all_para_combination, number_of_core=8, risk_free_r
     pool.map(mp_cal_performance, cal_performance_list)
     pool.close()
 
-    pd.DataFrame(list(manager_list)).to_csv('backtest_result.csv')
+    df_backtest_result = pd.DataFrame(list(manager_list))
+    df_backtest_result = df_backtest_result.sort_values(by='reference_index')
+    df_backtest_result.reset_index(drop=True)
+    df_backtest_result.to_csv('backtest_result.csv')
 
 
 def plot_signal_analysis(py_filename, output_folder, start_date, end_date, para_dict, signal_settings):
@@ -312,6 +315,7 @@ def calculate_win_rate_info(df):
 def calculate_win_rate(df_csv):
     df = df_csv[['date', 'realized_pnl', 'action']].copy()
     df = df[df['action'].notnull()].reset_index(drop=True)
+    df = df.loc[df['action'] != '']  # for parquet
     df['date'] = pd.to_datetime(df['date'], format='%Y-%m-%d')
     df['pnl'] = df['realized_pnl'].shift(-1)
     df['year'] = pd.DatetimeIndex(df['date']).year
@@ -600,7 +604,15 @@ def cal_performance(para_combination):
             year_count.append(result_dict[str(year)])
 
 
-        result_dict['cov_count'] = round(np.std(year_count) / np.mean(year_count), 3)
+        # result_dict['cov_count'] = round(np.std(year_count) / np.mean(year_count), 3)
+
+        std_dev = np.std(year_count)
+        mean = np.mean(year_count)
+
+        if std_dev != 0 and not np.isnan(std_dev) and mean != 0 and not np.isnan(mean):
+            result_dict['cov_count'] = round(std_dev / mean, 3)
+        else:
+            result_dict['cov_count'] = 0  # Assign a value indicating an invalid result
 
 
         # Performance by year
@@ -637,6 +649,9 @@ def cal_performance(para_combination):
 
     result_dict['risk_free_rate'] = risk_free_rate
 
+
+
+
     # BaH Performance
     bah_net_return, holding_period_day, bah_return, \
     bah_annualized_return, bah_annualized_std, bah_annualized_sr = calculate_sharpe_ratio(df, 'close',
