@@ -32,8 +32,8 @@ class Components:
                                                        {'label': 'Annualized Return <', 'value': 'annualized_return<'},
                                                        {'label': 'Return-BaH % Diff. >', 'value': 'return_to_bah>'},
                                                        {'label': 'Return-BaH % Diff. <', 'value': 'return_to_bah<'},
-                                                       {'label': 'Sharp Ratio >', 'value': 'annualized_sr>'},
-                                                       {'label': 'Sharp Ratio <', 'value': 'annualized_sr<'},
+                                                       {'label': 'Sharpe Ratio >', 'value': 'annualized_sr>'},
+                                                       {'label': 'Sharpe Ratio <', 'value': 'annualized_sr<'},
                                                        {'label': 'MDD Percentage >', 'value': 'mdd_pct>'},
                                                        {'label': 'MDD Percentage <', 'value': 'mdd_pct<'},
                                                        {'label': 'Trade Count >', 'value': 'num_of_trade>'},
@@ -78,7 +78,7 @@ class Components:
                        value=f'Top Net Profit',
                        options=[{'label': f'Top {number_of_curves} Net Profit', 'value': 'Top Net Profit'},
                                 {'label': f'Top {number_of_curves} Return-BaH % Difference', 'value': 'Top Return to BaH Ratio'},
-                                {'label': f'Top {number_of_curves} Sharp Ratio', 'value': 'Top Sharp Ratio'}, ],
+                                {'label': f'Top {number_of_curves} Sharpe Ratio', 'value': 'Top Sharpe Ratio'}, ],
                        style={'border-radius': '5px', 'font-size': '12px', }),
             style={'padding-left': '15px', 'width': '235px'})
 
@@ -292,7 +292,7 @@ class Components:
         per_col_2_1.append(html.Div('Return on Capital'))
         per_col_2_1.append(html.Div('Ann. Return'))
         per_col_2_1.append(html.Div('Ann. Std'))
-        per_col_2_1.append(html.Div('Ann. Sharp Ratio'))
+        per_col_2_1.append(html.Div('Ann. Sharpe Ratio'))
         per_col_2_1.append(html.Div('MDD Dollar'))
         per_col_2_1.append(html.Div('MDD Percentage'))
 
@@ -404,7 +404,7 @@ class Components:
         'num_of_trade':'Trade Count',
         'return_on_capital': 'Return on Capital',
         'annualized_return': 'Annualized Return',
-        'annualized_sr': 'Sharp Ratio',
+        'annualized_sr': 'Sharpe Ratio',
         'mdd_pct':'MDD Percentage',
         'cov_count':'COV (Count)',
         'cov_return': 'COV (Return)',
@@ -439,7 +439,7 @@ class Components:
     def sort_method_df(self, sort_method, result_df, number_of_curves):
         if sort_method == 'Top Net Profit':
             df_sorted = result_df.sort_values(by='net_profit', ascending=False).head(number_of_curves).copy()
-        elif sort_method == 'Top Sharp Ratio':
+        elif sort_method == 'Top Sharpe Ratio':
             df_sorted = result_df.sort_values(by='annualized_sr', ascending=False).head(number_of_curves).copy()
         elif sort_method == 'Top Return to BaH Ratio':
             df_sorted = result_df.sort_values(by='return_to_bah', ascending=False).head(number_of_curves).copy()
@@ -610,7 +610,7 @@ class Components:
 
             hovertemplate = hovertemplate + "Return on Capital : " + "{:.0%}".format(graph_df.iloc[i]['return_on_capital']/100) + "<br>"
             hovertemplate = hovertemplate + "Annual Return : " + "{:.0%}".format(graph_df.iloc[i]['annualized_return'] / 100) + "<br>"
-            hovertemplate = hovertemplate + "Sharp Ratio : " + str(graph_df.iloc[i]['annualized_sr']) + "<br>"
+            hovertemplate = hovertemplate + "Sharpe Ratio : " + str(graph_df.iloc[i]['annualized_sr']) + "<br>"
             hovertemplate = hovertemplate + "MDD Percentage : " + "{:.0%}".format(graph_df.iloc[i]['mdd_pct'] / 100) + "<br>"
 
             hovertemplate = hovertemplate + "<br>"
@@ -1101,7 +1101,7 @@ class Components:
                     'num_of_win': row['num_of_win'],
                     'return_on_capital': row['return_on_capital'],
                     'total_commission': row['total_commission'],
-                    'sharp_ratio': row['sharp'],
+                    'sharpe_ratio': row['sharpe'],
                 }
                 dict['format'] = file_format
                 dict['ref'] = ref_code
@@ -1279,7 +1279,7 @@ class Components:
         except:
             win_rate = '--'
 
-        # Sharp Ratio
+        # Sharpe Ratio
         annualized_std = total_dict['annualized_std']
         annualized_return = total_dict['annualized_return']
 
@@ -1335,6 +1335,7 @@ class Components:
                 year_return_list.append(0)
 
         cov_count = round(np.std(year_count) / np.mean(year_count), 2)
+
         if np.mean(year_return_list) == 0:
             cov_return = 0
         else:
@@ -1359,7 +1360,7 @@ class Components:
                          html.Div('Return on Capital'),
                          html.Div('Ann. Return'),
                          html.Div('Ann. Std'),
-                         html.Div('Ann. Sharp Ratio'),
+                         html.Div('Ann. Sharpe Ratio'),
                          html.Div('MDD Dollar'),
                          html.Div('MDD Percentage')
                          ],
